AdmobPlanifMax class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- appIdAdMob → String
-
no setter
- appOpenAdUnitId → String
-
no setter
-
no setter
- interstitielAdUnitId → String
-
no setter
- natifAdvancedAdUnitId → String
-
no setter
- rewardedInterstitialAdUnitId → String
-
no setter
- rewardedVideoAdUnitId → String
-
no setter
Constants
- appIdAdMobAndroid → const String
- appIdAdMobIOS → const String
- appOpenAdMobAndroid → const String
- appOpenAdMobIOS → const String
- interstitielAdMobAndroid → const String
- interstitielAdMobIOS → const String
- natifAdvancedAdMobAndroid → const String
- natifAdvancedAdMobIOS → const String
- rewardedAdMobAndroid → const String
- rewardedAdMobIOS → const String
- rewardedInterstitielAdMobAndroid → const String
- rewardedInterstitielAdMobIOS → const String