AdmobController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • AdmobController
Implemented types

Constructors

AdmobController({required SharedPreferences sharedPreferences})

Properties

appOpenAd ↔ AppOpenAd?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isHaveRecompenseAds bool
no setter
listeners int
no setterinherited
nbrClickCount int
no setter
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
recompenseAds int
no setter
recompenseAdsQR int
no setter
rewardAmount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedPreferences → SharedPreferences
final
showProgressBar bool
no setter

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
createAppOpenAd({bool showAfter = false}) Future
createInterstitialAd({bool showAfter = false}) Future
createRewardedAd() → void
createRewardedInterstitialAd() → void
dispose() → void
override
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getRecompenseAds() → dynamic
getRecompenseAdsQR() → dynamic
incrementAdClickCount() int
initAdMob() → dynamic
initRewardedVideoAd() → void
loadAndShowInterstitialAd() → dynamic
loadAndShowInterstitialAdQuickly() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onUserEarnedReward(AdWithoutView ad, RewardItem reward) → dynamic
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
resetAdClickCount() → dynamic
setRecompenseAds(int value) → dynamic
setRecompenseAdsQR(int value) → dynamic
setRewardAmount({required int action}) → void
setRewardAmountPlus({required int action, int amount = 0}) → void
setShowProgressBar({required bool show}) → dynamic
showActionsDialogAds({required String title, bool isSaveAfter = false, Function? setActionFunction}) → dynamic
showActionsDialogAds2({required String title, bool isSaveAfter = false, SetActionFunction? setActionFunction}) → dynamic
showAppOpenAd() → void
showDialogRecompense() → dynamic
showInterstitialAd() → void
showRewardedInterstitialAd() → void
showRewardedVideoAd() → dynamic
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited